:py:mod:`piel.models.frequency.all`
===================================

.. py:module:: piel.models.frequency.all


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.frequency.all.get_all_models



.. py:function:: get_all_models(custom_library: dict | None = None) -> dict

   Returns the default models dictionary.

   :param custom_library: Custom defaults dictionary.
   :type custom_library: dict

   :returns: Default models dictionary.
   :rtype: dict
